"use strict";
/*
 * MIT License
 *
 * Copyright (c) 2018 Choko (choko@curioswitch.org)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
}
Object.defineProperty(exports, "__esModule", { value: true });
// tslint:disable:no-var-requires
process.env.NODE_ENV = 'production';
require("typescript-register");
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const brotli_webpack_plugin_1 = __importDefault(require("brotli-webpack-plugin"));
const static_site_generator_webpack_plugin_1 = __importDefault(require("static-site-generator-webpack-plugin"));
const webapp_webpack_plugin_1 = __importDefault(require("webapp-webpack-plugin"));
const webpack_1 = require("webpack");
const zopfli_webpack_plugin_1 = __importDefault(require("zopfli-webpack-plugin"));
const base_1 = __importDefault(require("./base"));
const prerenderConfigPath = path_1.default.resolve(process.cwd(), 'src/prerender');
const prerenderConfig = fs_1.default.existsSync(prerenderConfigPath)
    ? require(prerenderConfigPath)
    : {
        paths: {
            '/': {},
        },
        globals: {},
    };
console.log(prerenderConfig);
const plugins = [
    new webpack_1.DefinePlugin({
        'process.env': {
            APP_CONFIG_PATH: JSON.stringify(path_1.default.resolve(process.cwd(), 'src/app')),
            NODE_ENV: JSON.stringify('production'),
        },
    }),
    new static_site_generator_webpack_plugin_1.default({
        entry: 'prerender',
        paths: Object.keys(prerenderConfig),
        locals: {
            pathStates: prerenderConfig.paths,
        },
        globals: Object.assign({ window: {
                ga: () => undefined,
            } }, prerenderConfig.globals),
    }),
    new webapp_webpack_plugin_1.default({
        logo: 'favicon.png',
        prefix: 'icons-[hash]/',
        emitStats: true,
        statsFilename: 'iconstats.json',
    }),
    new zopfli_webpack_plugin_1.default({
        asset: '[path].gz[query]',
        algorithm: 'zopfli',
        test: /\.(js|css|html|svg)$/,
        threshold: 1024,
        minRatio: 0.9,
    }),
    new brotli_webpack_plugin_1.default({
        asset: '[path].br[query]',
        test: /\.(js|css|html|svg)$/,
        threshold: 1024,
        minRatio: 0.9,
    }),
];
const configuration = base_1.default({
    plugins,
    mode: 'production',
    additionalEntrypoints: {
        prerender: path_1.default.resolve(__dirname, '../../prerender/index.tsx'),
    },
    babelPlugins: [
        '@babel/transform-react-constant-elements',
        '@babel/transform-react-inline-elements',
    ],
    output: {
        filename: '[name].[chunkhash].js',
        chunkFilename: '[name].[chunkhash].chunk.js',
        publicPath: '/static/',
        libraryTarget: 'commonjs',
    },
});
exports.default = configuration;
//# sourceMappingURL=prod.js.map